aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorGravatar Sadie Powell2024-09-27 18:30:11 +0100
committerGravatar Sadie Powell2024-09-27 18:30:11 +0100
commitb0a73189dbbcf9a73e791e7e65e6a349f01eac6e (patch)
tree945d4a89614ecf87b8c19766b21e07c557f4f1b8 /include
parentMake it clear that Anope 2.1 does not need cmode or umode +r. (diff)
Clean up the names of some variables in the extban header.
Diffstat (limited to 'include')
-rw-r--r--include/modules/extban.h62
1 files changed, 31 insertions, 31 deletions
diff --git a/include/modules/extban.h b/include/modules/extban.h
index 427e638e3..b5d8cea2c 100644
--- a/include/modules/extban.h
+++ b/include/modules/extban.h
@@ -88,10 +88,10 @@ class ExtBan::Manager
{
protected:
/** Initializes an instance of the ExtBan::Base class.
* @param Creator The module which created this instance.
*/
- Manager(Module* Creator)
- : DataProvider(Creator, "extbanmanager")
+ Manager(Module* mod)
+ : DataProvider(mod, "extbanmanager")
{
}
@@ -150,14 +150,14 @@ public:
Base* Find(const std::string& xbname) const { return xbname.length() == 1 ? FindLetter(xbname[0]) : FindName(xbname); }
/** Finds an extban by letter.
* @param letter The letter of the extban to find.
*/
- virtual Base* FindLetter(unsigned char letter) const = 0;
+ virtual Base* FindLetter(unsigned char xbletter) const = 0;
/** Finds an extban by name.
* @param name The name of the extban to find.
*/
- virtual Base* FindName(const std::string& name) const = 0;
+ virtual Base* FindName(const std::string& xbname) const = 0;
};
/** Dynamic reference to the extban manager class. */
@@ -165,8 +165,8 @@ class ExtBan::ManagerRef final
: public dynamic_reference_nocheck<ExtBan::Manager>
{
public:
- ManagerRef(Module* Creator)
- : dynamic_reference_nocheck<ExtBan::Manager>(Creator, "extbanmanager")
+ ManagerRef(Module* mod)
+ : dynamic_reference_nocheck<ExtBan::Manager>(mod, "extbanmanager")
{
}
};
@@ -195,14 +195,14 @@ private:
protected:
/** Initializes an instance of the ExtBan::Base class.
* @param Creator The module which created this instance.
* @param Name The name used in bans to signify this extban.
* @param Letter The character used in bans to signify this extban.
*/
- Base(Module* Creator, const std::string& Name, unsigned char Letter)
- : ServiceProvider(Creator, Name, SERVICE_CUSTOM)
- , letter(ServerInstance->Config->ConfValue("extbans")->getCharacter(Name, Letter))
- , manager(Creator, "extbanmanager")
+ Base(Module* mod, const std::string& xbname, unsigned char xbletter)
+ : ServiceProvider(mod, xbname, SERVICE_CUSTOM)
+ , letter(ServerInstance->Config->ConfValue("extbans")->getCharacter(xbname, xbletter))
+ , manager(mod, "extbanmanager")
{
}
@@ -269,12 +269,12 @@ class ExtBan::ActingBase
{
protected:
/** Initializes an instance of the ExtBan::ActingBase class.
* @param Creator The module which created this instance.
* @param Name The name used in bans to signify this extban.
* @param Letter The character used in bans to signify this extban.
*/
- ActingBase(Module* Creator, const std::string& Name, unsigned char Letter)
- : Base(Creator, Name, Letter)
+ ActingBase(Module* mod, const std::string& xbname, unsigned char xbletter)
+ : Base(mod, xbname, xbletter)
{
}
@@ -302,12 +302,12 @@ class ExtBan::Acting
{
public:
/** Initializes an instance of the ExtBan::Acting class.
* @param Creator The module which created this instance.
* @param Name The name used in bans to signify this extban.
* @param Letter The character used in bans to signify this extban.
*/
- Acting(Module* Creator, const std::string& Name, unsigned char Letter)
- : ActingBase(Creator, Name, Letter)
+ Acting(Module* mod, const std::string& xbname, unsigned char xbletter)
+ : ActingBase(mod, xbname, xbletter)
{
}
@@ -332,12 +332,12 @@ class ExtBan::MatchingBase
{
protected:
/** Initializes an instance of the ExtBan::MatchingBase class.
* @param Creator The module which created this instance.
* @param Name The name used in bans to signify this extban.
* @param Letter The character used in bans to signify this extban.
*/
- MatchingBase(Module* Creator, const std::string& Name, unsigned char Letter)
- : Base(Creator, Name, Letter)
+ MatchingBase(Module* mod, const std::string& xbname, unsigned char xbletter)
+ : Base(mod, xbname, xbletter)
{
}
@@ -88,10 +88,10 @@ class ExtBan::Manager
protected:
/** Initializes an instance of the ExtBan::Base class.
- * @param Creator The module which created this instance.
+ * @param mod The module which created this instance.
*/
@@ -150,14 +150,14 @@ public:
Base* Find(const std::string& xbname) const { return xbname.length() == 1 ? FindLetter(xbname[0]) : FindName(xbname); }
/** Finds an extban by letter.
- * @param letter The letter of the extban to find.
+ * @param xbletter The letter of the extban to find.
*/
@@ -150,14 +150,14 @@ public:
/** Finds an extban by name.
- * @param name The name of the extban to find.
+ * @param xbname The name of the extban to find.
*/
@@ -195,14 +195,14 @@ private:
protected:
/** Initializes an instance of the ExtBan::Base class.
- * @param Creator The module which created this instance.
- * @param Name The name used in bans to signify this extban.
- * @param Letter The character used in bans to signify this extban.
+ * @param mod The module which created this instance.
+ * @param xbname The name used in bans to signify this extban.
+ * @param xbletter The character used in bans to signify this extban.
*/
@@ -269,12 +269,12 @@ class ExtBan::ActingBase
protected:
/** Initializes an instance of the ExtBan::ActingBase class.
- * @param Creator The module which created this instance.
- * @param Name The name used in bans to signify this extban.
- * @param Letter The character used in bans to signify this extban.
+ * @param mod The module which created this instance.
+ * @param xbname The name used in bans to signify this extban.
+ * @param xbletter The character used in bans to signify this extban.
*/
@@ -302,12 +302,12 @@ class ExtBan::Acting
public:
/** Initializes an instance of the ExtBan::Acting class.
- * @param Creator The module which created this instance.
- * @param Name The name used in bans to signify this extban.
- * @param Letter The character used in bans to signify this extban.
+ * @param mod The module which created this instance.
+ * @param xbname The name used in bans to signify this extban.
+ * @param xbletter The character used in bans to signify this extban.
*/
@@ -332,12 +332,12 @@ class ExtBan::MatchingBase
protected:
/** Initializes an instance of the ExtBan::MatchingBase class.
- * @param Creator The module which created this instance.
- * @param Name The name used in bans to signify this extban.
- * @param Letter The character used in bans to signify this extban.
+ * @param mod The module which created this instance.
+ * @param xbname The name used in bans to signify this extban.
+ * @param xbletter The character used in bans to signify this extban.
*/